/* 
 * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#include "stdafx.h"
#include "../stub_wizard.h"
#include "../stub_view.h"
#include "base/string_utilities.h"


namespace mforms{
namespace stub{


//------------------------------------------------------------------------------
WizardImpl::WizardImpl(::mforms::Wizard *wiz)
    : ObjectImpl(wiz)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::cancel(::mforms::Wizard* wiz)
{
}

//------------------------------------------------------------------------------
bool __stdcall WizardImpl::create(::mforms::Wizard *self)
{
  return true;
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_title(::mforms::Wizard *self, const std::string &title)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::run_modal(::mforms::Wizard *self)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::close(::mforms::Wizard *self)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::flush_events(::mforms::Wizard *self)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_content(::mforms::Wizard *self, View *view)
{
}

//------------------------------------------------------------------------------
void WizardImpl::set_heading(::mforms::Wizard *self, const std::string &heading)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_step_list(::mforms::Wizard *self, const std::vector<std::string> &steps)
{
}


//------------------------------------------------------------------------------
void WizardImpl::refresh_step_list(const std::vector<std::string> &steps)
{
}

//------------------------------------------------------------------------------
void WizardImpl::set_icon_path(const std::string &path)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_allow_cancel(::mforms::Wizard *self, bool flag)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_allow_back(::mforms::Wizard *self, bool flag)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_allow_next(::mforms::Wizard *self, bool flag)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_show_extra(::mforms::Wizard *self, bool flag)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_extra_caption(::mforms::Wizard *self, const std::string &caption)
{
}

//------------------------------------------------------------------------------
void __stdcall WizardImpl::set_next_caption(::mforms::Wizard *self, const std::string &caption)
{
}

//------------------------------------------------------------------------------
void WizardImpl::init()
{
  ::mforms::ControlFactory *f= ::mforms::ControlFactory::get_instance();

  f->_wizard_impl.create = &WizardImpl::create;
  f->_wizard_impl.set_title = &WizardImpl::set_title;
  f->_wizard_impl.run_modal = &WizardImpl::run_modal;
  f->_wizard_impl.close = &WizardImpl::close;

  f->_wizard_impl.flush_events = &WizardImpl::flush_events;
  
  f->_wizard_impl.set_content = &WizardImpl::set_content;
  f->_wizard_impl.set_heading = &WizardImpl::set_heading;
  f->_wizard_impl.set_step_list = &WizardImpl::set_step_list;
  f->_wizard_impl.set_allow_cancel = &WizardImpl::set_allow_cancel;
  f->_wizard_impl.set_allow_back = &WizardImpl::set_allow_back;
  f->_wizard_impl.set_allow_next = &WizardImpl::set_allow_next;
  f->_wizard_impl.set_show_extra = &WizardImpl::set_show_extra;

  f->_wizard_impl.set_extra_caption = &WizardImpl::set_extra_caption;
  f->_wizard_impl.set_next_caption = &WizardImpl::set_next_caption;
}


}//end of stub namespace
}//end of mforms namespace
 
